@@ -36,7 +36,33 @@ __protobuf__ = proto.module(
 
 
 class OperationState(proto.Enum):
-    r"""Describes the state of the operation."""
+    r"""Describes the state of the operation.
+
+    Values:
+        OPERATION_STATE_UNSPECIFIED (0):
+            Unspecified.
+        INITIALIZING (1):
+            Request is being prepared for processing.
+        PROCESSING (2):
+            Request is actively being processed.
+        CANCELLING (3):
+            Request is in the process of being cancelled
+            after user called
+            google.longrunning.Operations.CancelOperation on
+            the operation.
+        FINALIZING (4):
+            Request has been processed and is in its
+            finalization stage.
+        SUCCESSFUL (5):
+            Request has completed successfully.
+        FAILED (6):
+            Request has finished being processed, but
+            encountered an error.
+        CANCELLED (7):
+            Request has finished being cancelled after
+            user called
+            google.longrunning.Operations.CancelOperation.
+    """
     OPERATION_STATE_UNSPECIFIED = 0
     INITIALIZING = 1
     PROCESSING = 2
@@ -145,7 +171,16 @@ class FieldOperationMetadata(proto.Message):
         """
 
         class ChangeType(proto.Enum):
-            r"""Specifies how the index is changing."""
+            r"""Specifies how the index is changing.
+
+            Values:
+                CHANGE_TYPE_UNSPECIFIED (0):
+                    The type of change is not specified or known.
+                ADD (1):
+                    The single field index is being added.
+                REMOVE (2):
+                    The single field index is being removed.
+            """
             CHANGE_TYPE_UNSPECIFIED = 0
             ADD = 1
             REMOVE = 2
@@ -171,7 +206,16 @@ class FieldOperationMetadata(proto.Message):
         """
 
         class ChangeType(proto.Enum):
-            r"""Specifies how the TTL config is changing."""
+            r"""Specifies how the TTL config is changing.
+
+            Values:
+                CHANGE_TYPE_UNSPECIFIED (0):
+                    The type of change is not specified or known.
+                ADD (1):
+                    The TTL config is being added.
+                REMOVE (2):
+                    The TTL config is being removed.
+            """
             CHANGE_TYPE_UNSPECIFIED = 0
             ADD = 1
             REMOVE = 2
