@@ -19,6 +19,9 @@ from google.api_core import retry as retries
 
 from google.cloud.firestore_v1 import _helpers
 from google.cloud.firestore_v1.document import DocumentReference
+from google.cloud.firestore_v1.base_aggregation import BaseAggregationQuery
+
+
 from typing import (
     Any,
     AsyncGenerator,
@@ -107,6 +110,9 @@ class BaseCollectionReference(object):
     def _query(self) -> BaseQuery:
         raise NotImplementedError
 
+    def _aggregation_query(self) -> BaseAggregationQuery:
+        raise NotImplementedError
+
     def document(self, document_id: str = None) -> DocumentReference:
         """Create a sub-document underneath the current collection.
 
@@ -474,6 +480,15 @@ class BaseCollectionReference(object):
     def on_snapshot(self, callback) -> NoReturn:
         raise NotImplementedError
 
+    def count(self, alias=None):
+        """
+        Adds a count over the nested query.
+
+        :type alias: str
+        :param alias: (Optional) The alias for the count
+        """
+        return self._aggregation_query().count(alias=alias)
+
 
 def _auto_id() -> str:
     """Generate a "random" automatically generated ID.
