@@ -22,9 +22,10 @@ from google.cloud.firestore_v1.base_collection import (
     _item_to_document_ref,
 )
 from google.cloud.firestore_v1 import query as query_mod
+from google.cloud.firestore_v1 import aggregation
 from google.cloud.firestore_v1.watch import Watch
 from google.cloud.firestore_v1 import document
-from typing import Any, Callable, Generator, Tuple
+from typing import Any, Callable, Generator, Tuple, Union
 
 # Types needed only for Type Hints
 from google.cloud.firestore_v1.transaction import Transaction
@@ -67,12 +68,20 @@ class CollectionReference(BaseCollectionReference):
         """
         return query_mod.Query(self)
 
+    def _aggregation_query(self) -> aggregation.AggregationQuery:
+        """AggregationQuery factory.
+
+        Returns:
+            :class:`~google.cloud.firestore_v1.aggregation_query.AggregationQuery`
+        """
+        return aggregation.AggregationQuery(self._query())
+
     def add(
         self,
         document_data: dict,
-        document_id: str = None,
+        document_id: Union[str, None] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, None] = None,
     ) -> Tuple[Any, Any]:
         """Create a document in the Firestore database with the provided data.
 
@@ -112,9 +121,9 @@ class CollectionReference(BaseCollectionReference):
 
     def list_documents(
         self,
-        page_size: int = None,
+        page_size: Union[int, None] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, None] = None,
     ) -> Generator[Any, Any, None]:
         """List all subdocuments of the current collection.
 
@@ -147,9 +156,9 @@ class CollectionReference(BaseCollectionReference):
 
     def get(
         self,
-        transaction: Transaction = None,
+        transaction: Union[Transaction, None] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, None] = None,
     ) -> list:
         """Read the documents in this collection.
 
@@ -178,9 +187,9 @@ class CollectionReference(BaseCollectionReference):
 
     def stream(
         self,
-        transaction: Transaction = None,
+        transaction: Union[Transaction, None] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, None] = None,
     ) -> Generator[document.DocumentSnapshot, Any, None]:
         """Read the documents in this collection.
 
