@@ -69,8 +69,8 @@ class FirestoreAsyncClient:
     syncing, and querying data for your mobile, web, and IoT apps at
     global scale. Its client libraries provide live synchronization
     and offline support, while its security features and
-    integrations with Firebase and Google Cloud Platform (GCP)
-    accelerate building truly serverless apps.
+    integrations with Firebase and Google Cloud Platform accelerate
+    building truly serverless apps.
     """
 
     _client: FirestoreClient
@@ -348,7 +348,6 @@ class FirestoreAsyncClient:
                 request = firestore_v1.ListDocumentsRequest(
                     transaction=b'transaction_blob',
                     parent="parent_value",
-                    collection_id="collection_id_value",
                 )
 
                 # Make the request
@@ -371,7 +370,7 @@ class FirestoreAsyncClient:
         Returns:
             google.cloud.firestore_v1.services.firestore.pagers.ListDocumentsAsyncPager:
                 The response for
-                [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
+                   [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -718,7 +717,7 @@ class FirestoreAsyncClient:
         Returns:
             AsyncIterable[google.cloud.firestore_v1.types.BatchGetDocumentsResponse]:
                 The streamed response for
-                [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
+                   [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
 
         """
         # Create or coerce a protobuf request object.
@@ -818,7 +817,7 @@ class FirestoreAsyncClient:
         Returns:
             google.cloud.firestore_v1.types.BeginTransactionResponse:
                 The response for
-                [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
+                   [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
 
         """
         # Create or coerce a protobuf request object.
@@ -1162,7 +1161,7 @@ class FirestoreAsyncClient:
         Returns:
             AsyncIterable[google.cloud.firestore_v1.types.RunQueryResponse]:
                 The response for
-                [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
+                   [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
 
         """
         # Create or coerce a protobuf request object.
@@ -1270,7 +1269,7 @@ class FirestoreAsyncClient:
         Returns:
             AsyncIterable[google.cloud.firestore_v1.types.RunAggregationQueryResponse]:
                 The response for
-                [Firestore.RunAggregationQuery][google.firestore.v1.Firestore.RunAggregationQuery].
+                   [Firestore.RunAggregationQuery][google.firestore.v1.Firestore.RunAggregationQuery].
 
         """
         # Create or coerce a protobuf request object.
@@ -1367,7 +1366,7 @@ class FirestoreAsyncClient:
         Returns:
             google.cloud.firestore_v1.services.firestore.pagers.PartitionQueryAsyncPager:
                 The response for
-                [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
+                   [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -1431,7 +1430,8 @@ class FirestoreAsyncClient:
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Awaitable[AsyncIterable[firestore.WriteResponse]]:
         r"""Streams batches of document updates and deletes, in
-        order.
+        order. This method is only available via the gRPC API
+        (not REST).
 
         .. code-block:: python
 
@@ -1528,7 +1528,8 @@ class FirestoreAsyncClient:
         timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Awaitable[AsyncIterable[firestore.ListenResponse]]:
-        r"""Listens to changes.
+        r"""Listens to changes. This method is only available via
+        the gRPC API (not REST).
 
         .. code-block:: python
 
@@ -1683,7 +1684,7 @@ class FirestoreAsyncClient:
         Returns:
             google.cloud.firestore_v1.services.firestore.pagers.ListCollectionIdsAsyncPager:
                 The response from
-                [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
+                   [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -1811,7 +1812,7 @@ class FirestoreAsyncClient:
         Returns:
             google.cloud.firestore_v1.types.BatchWriteResponse:
                 The response from
-                [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
+                   [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
 
         """
         # Create or coerce a protobuf request object.
