@@ -237,7 +237,18 @@ class DocumentTransform(proto.Message):
         """
 
         class ServerValue(proto.Enum):
-            r"""A value that is calculated by the server."""
+            r"""A value that is calculated by the server.
+
+            Values:
+                SERVER_VALUE_UNSPECIFIED (0):
+                    Unspecified. This value must not be used.
+                REQUEST_TIME (1):
+                    The time at which the server processed the
+                    request, with millisecond precision. If used on
+                    multiple fields (same or different documents) in
+                    a transaction, all the fields will get the same
+                    server timestamp.
+            """
             SERVER_VALUE_UNSPECIFIED = 0
             REQUEST_TIME = 1
 
