@@ -19,6 +19,8 @@ import math
 import pytest
 import pytest_asyncio
 import operator
+import google.auth
+
 from typing import Callable, Dict, List, Optional
 
 from google.oauth2 import service_account
@@ -65,11 +67,13 @@ def _get_credentials_and_project():
     if FIRESTORE_EMULATOR:
         credentials = EMULATOR_CREDS
         project = FIRESTORE_PROJECT
-    else:
+    elif FIRESTORE_CREDS:
         credentials = service_account.Credentials.from_service_account_file(
             FIRESTORE_CREDS
         )
         project = FIRESTORE_PROJECT or credentials.project_id
+    else:
+        credentials, project = google.auth.default()
     return credentials, project
 
 
@@ -579,6 +583,14 @@ async def query_docs(client):
         await operation()
 
 
+@pytest_asyncio.fixture
+async def async_query(query_docs):
+    collection, stored, allowed_vals = query_docs
+    query = collection.where("a", "==", 1)
+
+    return query
+
+
 async def test_query_stream_w_simple_field_eq_op(query_docs):
     collection, stored, allowed_vals = query_docs
     query = collection.where("a", "==", 1)
@@ -1399,3 +1411,184 @@ async def _chain(*iterators):
     for iterator in iterators:
         async for value in iterator:
             yield value
+
+
+async def test_count_async_query_get_default_alias(async_query):
+    count_query = async_query.count()
+    result = await count_query.get()
+    for r in result[0]:
+        assert r.alias == "field_1"
+
+
+async def test_async_count_query_get_with_alias(async_query):
+
+    count_query = async_query.count(alias="total")
+    result = await count_query.get()
+    for r in result[0]:
+        assert r.alias == "total"
+
+
+async def test_async_count_query_get_with_limit(async_query):
+
+    count_query = async_query.count(alias="total")
+    result = await count_query.get()
+    for r in result[0]:
+        assert r.alias == "total"
+        assert r.value == 5
+
+    # count with limit
+    count_query = async_query.limit(2).count(alias="total")
+    result = await count_query.get()
+    for r in result[0]:
+        assert r.alias == "total"
+        assert r.value == 2
+
+
+async def test_async_count_query_get_multiple_aggregations(async_query):
+
+    count_query = async_query.count(alias="total").count(alias="all")
+
+    result = await count_query.get()
+    assert len(result[0]) == 2
+
+    expected_aliases = ["total", "all"]
+    found_alias = set(
+        [r.alias for r in result[0]]
+    )  # ensure unique elements in the result
+    assert len(found_alias) == 2
+    assert found_alias == set(expected_aliases)
+
+
+async def test_async_count_query_get_multiple_aggregations_duplicated_alias(
+    async_query,
+):
+
+    count_query = async_query.count(alias="total").count(alias="total")
+
+    with pytest.raises(InvalidArgument) as exc_info:
+        await count_query.get()
+
+    assert "Aggregation aliases contain duplicate alias" in exc_info.value.message
+
+
+async def test_async_count_query_get_empty_aggregation(async_query):
+    from google.cloud.firestore_v1.async_aggregation import AsyncAggregationQuery
+
+    aggregation_query = AsyncAggregationQuery(async_query)
+
+    with pytest.raises(InvalidArgument) as exc_info:
+        await aggregation_query.get()
+
+    assert "Aggregations can not be empty" in exc_info.value.message
+
+
+async def test_count_async_query_stream_default_alias(async_query):
+
+    count_query = async_query.count()
+
+    async for result in count_query.stream():
+        for aggregation_result in result:
+            assert aggregation_result.alias == "field_1"
+
+
+async def test_async_count_query_stream_with_alias(async_query):
+
+    count_query = async_query.count(alias="total")
+    async for result in count_query.stream():
+        for aggregation_result in result:
+            assert aggregation_result.alias == "total"
+
+
+async def test_async_count_query_stream_with_limit(async_query):
+    # count without limit
+    count_query = async_query.count(alias="total")
+    async for result in count_query.stream():
+        for aggregation_result in result:
+            assert aggregation_result.value == 5
+
+    # count with limit
+    count_query = async_query.limit(2).count(alias="total")
+    async for result in count_query.stream():
+        for aggregation_result in result:
+            assert aggregation_result.value == 2
+
+
+async def test_async_count_query_stream_multiple_aggregations(async_query):
+
+    count_query = async_query.count(alias="total").count(alias="all")
+
+    async for result in count_query.stream():
+        assert len(result) == 2
+        for aggregation_result in result:
+            assert aggregation_result.alias in ["total", "all"]
+
+
+async def test_async_count_query_stream_multiple_aggregations_duplicated_alias(
+    async_query,
+):
+
+    count_query = async_query.count(alias="total").count(alias="total")
+
+    with pytest.raises(InvalidArgument) as exc_info:
+        async for _ in count_query.stream():
+            pass
+
+    assert "Aggregation aliases contain duplicate alias" in exc_info.value.message
+
+
+async def test_async_count_query_stream_empty_aggregation(async_query):
+    from google.cloud.firestore_v1.async_aggregation import AsyncAggregationQuery
+
+    aggregation_query = AsyncAggregationQuery(async_query)
+
+    with pytest.raises(InvalidArgument) as exc_info:
+        async for _ in aggregation_query.stream():
+            pass
+
+    assert "Aggregations can not be empty" in exc_info.value.message
+
+
+@firestore.async_transactional
+async def create_in_transaction_helper(transaction, client, collection_id, cleanup):
+    collection = client.collection(collection_id)
+    query = collection.where("a", "==", 1)
+    count_query = query.count()
+    result = await count_query.get(transaction=transaction)
+
+    for r in result[0]:
+        if r.value < 2:
+            document_id_3 = "doc3" + UNIQUE_RESOURCE_ID
+            document_3 = client.document(collection_id, document_id_3)
+            cleanup(document_3.delete)
+            document_3.create({"a": 1})
+        else:  # transaction is rolled back
+            raise ValueError("Collection can't have more than 2 docs")
+
+
+async def test_count_query_in_transaction(client, cleanup):
+    collection_id = "doc-create" + UNIQUE_RESOURCE_ID
+    document_id_1 = "doc1" + UNIQUE_RESOURCE_ID
+    document_id_2 = "doc2" + UNIQUE_RESOURCE_ID
+
+    document_1 = client.document(collection_id, document_id_1)
+    document_2 = client.document(collection_id, document_id_2)
+
+    cleanup(document_1.delete)
+    cleanup(document_2.delete)
+
+    await document_1.create({"a": 1})
+    await document_2.create({"a": 1})
+
+    transaction = client.transaction()
+
+    with pytest.raises(ValueError) as exc:
+        await create_in_transaction_helper(transaction, client, collection_id, cleanup)
+        assert exc.exc_info == "Collection can't have more than 2 documents"
+
+    collection = client.collection(collection_id)
+
+    query = collection.where("a", "==", 1)
+    count_query = query.count()
+    result = await count_query.get()
+    for r in result[0]:
+        assert r.value == 2  # there are still only 2 docs
